@@ -3,6 +3,7 @@ from __future__ import annotations
 import os
 
 from auto_editor.ffwrapper import FFmpeg, FileInfo
+from auto_editor.output import Ensure
 from auto_editor.timeline import Timeline, make_timeline
 from auto_editor.utils.bar import Bar
 from auto_editor.utils.chunks import Chunk, Chunks
@@ -53,9 +54,6 @@ def set_video_codec(
             log.error("Input file does not have a video stream to copy codec from.")
         codec = inp.videos[0].codec
 
-    if codec == "uncompressed":
-        codec = "mpeg4"
-
     if ctr.vstrict:
         assert ctr.vcodecs is not None
         if codec not in ctr.vcodecs:
@@ -114,7 +112,7 @@ def edit_media(
             timeline = read_json(paths[0], ffmpeg, log)
             inputs: list[FileInfo] = timeline.inputs
         else:
-            inputs = [FileInfo(path, ffmpeg, log) for path in paths]
+            inputs = [FileInfo(i, istr, ffmpeg, log) for i, istr in enumerate(paths)]
     else:
         inputs = []
     del paths
@@ -163,13 +161,6 @@ def edit_media(
         ffmpeg.run(cmd)
         del inp
 
-    log.conwrite("Extracting audio")
-
-    cmd = []
-    for i, inp in enumerate(inputs):
-        cmd.extend(["-i", inp.path])
-    cmd.append("-hide_banner")
-
     if args.sample_rate is None:
         if inputs:
             samplerate = inputs[0].get_samplerate()
@@ -178,26 +169,10 @@ def edit_media(
     else:
         samplerate = args.sample_rate
 
-    for i, inp in enumerate(inputs):
-        for s in range(len(inp.audios)):
-            cmd.extend(
-                [
-                    "-map",
-                    f"{i}:a:{s}",
-                    "-ac",
-                    "2",
-                    "-ar",
-                    f"{samplerate}",
-                    "-rf64",
-                    "always",
-                    os.path.join(temp, f"{i}-{s}.wav"),
-                ]
-            )
-
-    ffmpeg.run(cmd)
+    ensure = Ensure(ffmpeg, samplerate, temp, log)
 
     if timeline is None:
-        timeline = make_timeline(inputs, args, samplerate, bar, temp, log)
+        timeline = make_timeline(inputs, ensure, args, samplerate, bar, temp, log)
 
     if args.timeline:
         from auto_editor.formats.json import make_json_timeline
@@ -208,7 +183,7 @@ def edit_media(
     if args.preview:
         from auto_editor.preview import preview
 
-        preview(timeline, temp, log)
+        preview(ensure, timeline, temp, log)
         return None
 
     if out_ext == "json":
@@ -221,7 +196,7 @@ def edit_media(
     if args.export == "premiere":
         from auto_editor.formats.premiere import premiere_xml
 
-        premiere_xml(temp, output, timeline)
+        premiere_xml(ensure, output, timeline)
         return output
 
     if args.export == "final-cut-pro":
@@ -253,7 +228,7 @@ def edit_media(
         if ctr.allow_audio:
             from auto_editor.render.audio import make_new_audio
 
-            audio_output = make_new_audio(timeline, ffmpeg, bar, temp, log)
+            audio_output = make_new_audio(timeline, ensure, ffmpeg, bar, temp, log)
 
         if ctr.allow_video:
             if len(timeline.v) > 0:
@@ -306,7 +281,7 @@ def edit_media(
                 continue
 
             _c = pad_chunk(chunk, total_frames)
-            vspace, aspace = make_av([clipify(_c, 0)], [inp])
+            vspace, aspace = make_av([clipify(_c, 0)], [timeline.inputs[0]])
             my_timeline = Timeline(
                 timeline.inputs,
                 timeline.timebase,
