@@ -108,9 +108,11 @@ def time(val: str) -> int | str:
     if unit in ("h", "hour", "hours"):
         return str(num * 3600)
 
-    _unit_check(unit, ("", "f", "frame", "frames"))
+    _unit_check(unit, ("",))
     if not isinstance(num, int) and not num.is_integer():
-        raise TypeError(f"'{val}': Frame unit doesn't accept non-ints.")
+        raise TypeError(
+            f"'{val}': Time uses ticks by default and ticks doesn't accept non-ints."
+        )
     return int(num)
 
 
@@ -208,7 +210,7 @@ def pos(val: tuple[float | str, int]) -> int:
 
 @dataclass
 class MainArgs:
-    pool: list[tuple[str, str]] = field(default_factory=list)
+    add: list[str] = field(default_factory=list)
     yt_dlp_location: str = "yt-dlp"
     download_format: str | None = None
     output_format: str | None = None
